StateRegistry

Struct StateRegistry 

pub struct StateRegistry {
    database: SystemDatabase,
    client_managed: RwLock<HashMap<TypeId, Box<dyn Any + Send + Sync>>>,
}
A registry that contains repositories for different types of items. These repositories can be either managed by the client or by the SDK itself.

Fields

database: SystemDatabaseclient_managed: RwLock<HashMap<TypeId, Box<dyn Any + Send + Sync>>>

Implementations

Source

impl StateRegistry

pub fn new_with_memory_db() -> Self

Creates a new StateRegistry backed by an in-memory database.

pub async fn new_with_db( configuration: DatabaseConfiguration, migrations: RepositoryMigrations, ) -> Result<Self, DatabaseError>

Creates a new StateRegistry backed by a database.

pub fn setting<T>(&self, key: Key<T>) -> Result<Setting<T>, StateRegistryError>

Get a handle to a setting by its type-safe key.

pub fn register_client_managed<T: RepositoryItem>( &self, value: Arc<dyn Repository<T>>, )

Registers a client-managed repository into the map, associating it with its type.

fn get_client_managed<T: RepositoryItem>( &self, ) -> Option<Arc<dyn Repository<T>>>

Retrieves a client-managed repository from the map given its type.

fn get_sdk_managed<T: RepositoryItem>( &self, ) -> Result<Arc<dyn Repository<T>>, StateRegistryError>

Retrieves a SDK-managed repository from the database.

pub fn get<T>(&self) -> Result<Arc<dyn Repository<T>>, StateRegistryError>
where T: RepositoryItem,

Get a repository with fallback: prefer client-managed, fall back to SDK-managed.

This method first attempts to retrieve a client-managed repository. If not found, it falls back to an SDK-managed repository. Both are returned as Arc<dyn Repository<T>>.

Errors

This method never fails, but returns a Result for backwards compatibility.

pub async fn wipe(&self) -> Result<(), DatabaseError>

Wipes all state from this registry, and deletes any files or databases associated with it. Intended to be used during logout, where the Client will be dropped right after.

Warning

This closes the SDK-managed database and deletes persistent storage (SQLite file + WAL/SHM, IndexedDB database). Outstanding Repository handles will return DatabaseError::Closed on subsequent operations. Client-managed repositories are also cleared.